@@ -14,7 +14,7 @@
 from decimal import Decimal
 import logging
 
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from horizon import exceptions as horizon_exceptions
 from horizon import forms
 from horizon import messages
