@@ -12,11 +12,11 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.conf.urls import url
+from django.urls import re_path
 
 from cloudkittydashboard.dashboards.project.rating import views
 
 urlpatterns = [
-    url(r'^$', views.IndexView.as_view(), name='index'),
-    url(r'^quote$', views.quote, name='quote')
+    re_path(r'^$', views.IndexView.as_view(), name='index'),
+    re_path(r'^quote$', views.quote, name='quote')
 ]
